#!/bin/sh
#
# Author: pr2
# for: http://www.streamboard.tv
#
# Version: 1.0
# Date: 2013-03-21
#

printf "\nDVB favorite to playlist.m3u file convertor.\n"
printf "by Pr2 for http://www.streamboard.tv/\n\n"


IPADDR=$(ip addr show eth0 | awk '/inet / { print $2 }' | awk -F '/' '// { print $1  }')

if [  ${#IPADDR} -eq 0 ]; then
	IPADDR="192.168.1.123"
fi

if [ $# -lt 2 ]
   then
	printf "ERROR: Incorrect number of parameters, please provide the following parameters:\n"
	printf "%s \"full_path_to_userbouquet_file\" \"Serveur_IP\" \"Server_Port\"\n" $0
	printf "example:\n"
	printf "%s \"/etc/enigma2/userbouquet.csat_hd.tv\" \"%s\" \"8001\"\n" $0 $IPADDR
	exit 5
fi

if [ ! -f $1 ]
	then
		printf "ERROR: file not found %s\n" $1
		exit 5
fi

if [ $# -eq 3 ]; then
	SERVERPORT=$3
else
	SERVERPORT="8001"
fi

# Variables definition
#
# RESULTFILE : This will be the name of the script generated oscam.srvid file
#

BOUQUET="$1"
SERVERIP="$2"
FILETYPE=$(echo $BOUQUET | awk -F '.' 'END{print $NF}')
BOUQUETNAME=$(head -n1 $BOUQUET | dos2unix | sed 's/#NAME //g')
BOUQUETNAMEFILE=$(echo $BOUQUETNAME | sed 's/\W/_/g' )
RESULTFILE="playlist-"$BOUQUETNAMEFILE"".""$FILETYPE".m3u"

#
#############################################################
# Change the following only if you know what you do:
#
CHANNELFILE="index.idx"

#
# Internal variable
#

#
#
#
rm $RESULTFILE
clear
printf "userbouquet convertor to playlist[m3u]: %s\n" "$BOUQUET"
printf "_______________________________________\n"

if [ ! -f $CHANNELFILE ]; then
   printf "ERROR: file %s is missing, please check or run ./1lamedb.sh \n" $CHANNELFILE
   exit 5
fi

printf "#EXTM3U\n" >> "$RESULTFILE"
# printf "#EXTVLCOPT--http-reconnect=true \n" >> "$RESULTFILE"
while read line
do
	printf "\033[32m"
	printf "+"
	printf "\033[0m"
	BOUQUETLINE=$(echo $line | awk -v SERVERIP=$SERVERIP -v SERVERPORT=$SERVERPORT '
		/#SERVICE 1:0:/ {
			line=substr($0,0,length($0)-1)
			printf "http://%s:%s/%s\n", SERVERIP, SERVERPORT,  $2
			next
			}
	')

	SEARCHSTR=$( echo $line | awk -F ':' '
		/#SERVICE 1:0:/ { 
			if ( $2=="0" ) {
			printf "%04s:%08s:%04s\n", $4, $7, $5
			}
		}' 2>/dev/null | sed "s/ /0/g" )

	if [ ! ${#SEARCHSTR} -eq 0 ]; then
		result=$(grep -i $SEARCHSTR $CHANNELFILE)
		CHANNAME=$( echo $result | awk -F '|' '
		// { 
			printf "%s", $2
		}')
		echo $SEARCHSTR | awk -F ':' 'function mystrtonum(str,        ret, chars, n, i, k, c)
			 {
				 if (str ~ /^0[0-7]*$/) {
					 # octal
					 n = length(str)
					 ret = 0
					 for (i = 1; i <= n; i++) {
						 c = substr(str, i, 1)
						 if ((k = index("01234567", c)) > 0)
							 k-- # adjust for 1-basing in awk
			 
						 ret = ret * 8 + k
					 }
				 } else if (str ~ /^0[xX][[:xdigit:]]+/) {
					 # hexadecimal
					 str = substr(str, 3)    # lop off leading 0x
					 n = length(str)
					 ret = 0
					 for (i = 1; i <= n; i++) {
						 c = substr(str, i, 1)
						 c = tolower(c)
						 if ((k = index("0123456789", c)) > 0)
							 k-- # adjust for 1-basing in awk
						 else if ((k = index("abcdef", c)) > 0)
							 k += 9
			 
						 ret = ret * 16 + k
					 }
				 } else if (str ~ \
			   /^[-+]?([0-9]+([.][0-9]*([Ee][0-9]+)?)?|([.][0-9]+([Ee][-+]?[0-9]+)?))$/) {
					 # decimal number, possibly floating point
					 ret = str + 0
				 } else
					 ret = "NOT-A-NUMBER"
			 
				 return ret
			 }
		{printf "#EXTVLCOPT:program=%d\n", mystrtonum("0x"$1) }' >> "$RESULTFILE"
		printf "#EXTINF:0, %s - %s\n" "$BOUQUETNAME" "$CHANNAME" >> "$RESULTFILE"
		printf "%s\n" "$BOUQUETLINE" >> "$RESULTFILE"
	fi
done < "$BOUQUET"

printf "\nResult file is: %s\nDone.\n" "$RESULTFILE"
printf "Transfert %s to your client and open it up with VLC.\n" "$RESULTFILE"
printf "\nVLC homepage: http://www.videolan.org/\n"
printf "\nEnjoy! By Pr2 for http://www.streamboard.tv\n"
